# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKVoronoiPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkVoronoiSegmentationImageFilterPython
else:
    import _itkVoronoiSegmentationImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourceCommonPython
import itk.itkImageToImageFilterCommonPython

def itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_New():
    return itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass.New()

class itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_Pointer"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_Pointer"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_Clone(self)

    def SetNumberOfSeeds(self, _arg):
        r"""
        SetNumberOfSeeds(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetNumberOfSeeds(self, _arg)

    def GetNumberOfSeeds(self):
        r"""GetNumberOfSeeds(self) -> int"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetNumberOfSeeds(self)

    def SetMinRegion(self, _arg):
        r"""
        SetMinRegion(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetMinRegion(self, _arg)

    def GetMinRegion(self):
        r"""GetMinRegion(self) -> unsigned long"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetMinRegion(self)

    def SetSteps(self, _arg):
        r"""
        SetSteps(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetSteps(self, _arg)

    def GetSteps(self):
        r"""GetSteps(self) -> int"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetSteps(self)

    def GetLastStepSeeds(self):
        r"""GetLastStepSeeds(self) -> int"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetLastStepSeeds(self)

    def GetNumberOfSeedsToAdded(self):
        r"""GetNumberOfSeedsToAdded(self) -> int"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetNumberOfSeedsToAdded(self)

    def SetUseBackgroundInAPrior(self, _arg):
        r"""
        SetUseBackgroundInAPrior(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetUseBackgroundInAPrior(self, _arg)

    def GetUseBackgroundInAPrior(self):
        r"""GetUseBackgroundInAPrior(self) -> bool"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetUseBackgroundInAPrior(self)

    def SetOutputBoundary(self, _arg):
        r"""
        SetOutputBoundary(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetOutputBoundary(self, _arg)

    def GetOutputBoundary(self):
        r"""GetOutputBoundary(self) -> bool"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetOutputBoundary(self)

    def SetInteractiveSegmentation(self, _arg):
        r"""
        SetInteractiveSegmentation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetInteractiveSegmentation(self, _arg)

    def GetInteractiveSegmentation(self):
        r"""GetInteractiveSegmentation(self) -> bool"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetInteractiveSegmentation(self)

    def InteractiveSegmentationOn(self):
        r"""InteractiveSegmentationOn(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_InteractiveSegmentationOn(self)

    def InteractiveSegmentationOff(self):
        r"""InteractiveSegmentationOff(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_InteractiveSegmentationOff(self)

    def SetMeanDeviation(self, _arg):
        r"""
        SetMeanDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetMeanDeviation(self, _arg)

    def GetMeanDeviation(self):
        r"""GetMeanDeviation(self) -> double"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetMeanDeviation(self)

    def SetSize(self, _arg):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetSize(self, _arg)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetSize(self)

    def TakeAPrior(self, arg0):
        r"""
        TakeAPrior(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC2 const *

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_TakeAPrior(self, arg0)

    def RunSegment(self):
        r"""RunSegment(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_RunSegment(self)

    def RunSegmentOneStep(self):
        r"""RunSegmentOneStep(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_RunSegmentOneStep(self)

    def MakeSegmentBoundary(self):
        r"""MakeSegmentBoundary(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_MakeSegmentBoundary(self)

    def MakeSegmentObject(self):
        r"""MakeSegmentObject(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_MakeSegmentObject(self)

    def GetVoronoiDiagram(self):
        r"""GetVoronoiDiagram(self) -> itk::SmartPointer< itk::VoronoiDiagram2D< double > >"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetVoronoiDiagram(self)

    def SetSeeds(self, seeds):
        r"""
        SetSeeds(self, seeds)

        Parameters
        ----------
        seeds: std::vector< itkPointD2,std::allocator< itkPointD2 > > &

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_SetSeeds(self, seeds)

    def GetSeed(self, SeedID):
        r"""
        GetSeed(self, SeedID) -> itkPointD2

        Parameters
        ----------
        SeedID: int

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GetSeed(self, SeedID)

    def DrawDiagram(self, result, incolor, outcolor, boundcolor):
        r"""
        DrawDiagram(self, result, incolor, outcolor, boundcolor)

        Parameters
        ----------
        result: itkImageUC2_Pointer
        incolor: unsigned char
        outcolor: unsigned char
        boundcolor: unsigned char

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_DrawDiagram(self, result, incolor, outcolor, boundcolor)

    def BeforeNextStep(self):
        r"""BeforeNextStep(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_BeforeNextStep(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_GenerateInputRequestedRegion(self)
    __swig_destroy__ = _itkVoronoiSegmentationImageFilterPython.delete_itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass

        Create a new object of the class itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass in _itkVoronoiSegmentationImageFilterPython:
_itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass_swigregister(itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass)

def itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_New():
    return itkVoronoiSegmentationImageFilterIUC2IUC2IUC2.New()

class itkVoronoiSegmentationImageFilterIUC2IUC2IUC2(itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Superclass):
    r"""Proxy of C++ itkVoronoiSegmentationImageFilterIUC2IUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Pointer"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Pointer"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_Clone(self)

    def SetMean(self, _arg):
        r"""
        SetMean(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_SetMean(self, _arg)

    def GetMean(self):
        r"""GetMean(self) -> double"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_GetMean(self)

    def SetSTD(self, _arg):
        r"""
        SetSTD(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_SetSTD(self, _arg)

    def GetSTD(self):
        r"""GetSTD(self) -> double"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_GetSTD(self)

    def SetMeanTolerance(self, _arg):
        r"""
        SetMeanTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_SetMeanTolerance(self, _arg)

    def GetMeanTolerance(self):
        r"""GetMeanTolerance(self) -> double"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_GetMeanTolerance(self)

    def SetSTDTolerance(self, _arg):
        r"""
        SetSTDTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_SetSTDTolerance(self, _arg)

    def GetSTDTolerance(self):
        r"""GetSTDTolerance(self) -> double"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_GetSTDTolerance(self)

    def SetMeanPercentError(self, x):
        r"""
        SetMeanPercentError(self, x)

        Parameters
        ----------
        x: double

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_SetMeanPercentError(self, x)

    def GetMeanPercentError(self):
        r"""GetMeanPercentError(self) -> double"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_GetMeanPercentError(self)

    def GetSTDPercentError(self):
        r"""GetSTDPercentError(self) -> double"""
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_GetSTDPercentError(self)

    def SetSTDPercentError(self, x):
        r"""
        SetSTDPercentError(self, x)

        Parameters
        ----------
        x: double

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_SetSTDPercentError(self, x)
    SameDimensionCheck = _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_SameDimensionCheck
    
    IntConvertibleToOutputCheck = _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_IntConvertibleToOutputCheck
    
    __swig_destroy__ = _itkVoronoiSegmentationImageFilterPython.delete_itkVoronoiSegmentationImageFilterIUC2IUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVoronoiSegmentationImageFilterIUC2IUC2IUC2

        Create a new object of the class itkVoronoiSegmentationImageFilterIUC2IUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVoronoiSegmentationImageFilterIUC2IUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVoronoiSegmentationImageFilterIUC2IUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVoronoiSegmentationImageFilterIUC2IUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVoronoiSegmentationImageFilterIUC2IUC2IUC2 in _itkVoronoiSegmentationImageFilterPython:
_itkVoronoiSegmentationImageFilterPython.itkVoronoiSegmentationImageFilterIUC2IUC2IUC2_swigregister(itkVoronoiSegmentationImageFilterIUC2IUC2IUC2)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def voronoi_segmentation_image_filter(*args: itkt.ImageLike,  mean: float=..., std: float=..., mean_tolerance: float=..., std_tolerance: float=..., mean_percent_error: float=..., std_percent_error: float=..., number_of_seeds: int=..., min_region: int=..., steps: int=..., use_background_in_a_prior: bool=..., output_boundary: bool=..., interactive_segmentation: bool=..., mean_deviation: float=..., size: Sequence[int]=..., seeds=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for VoronoiSegmentationImageFilter"""
    import itk

    kwarg_typehints = { 'mean':mean,'std':std,'mean_tolerance':mean_tolerance,'std_tolerance':std_tolerance,'mean_percent_error':mean_percent_error,'std_percent_error':std_percent_error,'number_of_seeds':number_of_seeds,'min_region':min_region,'steps':steps,'use_background_in_a_prior':use_background_in_a_prior,'output_boundary':output_boundary,'interactive_segmentation':interactive_segmentation,'mean_deviation':mean_deviation,'size':size,'seeds':seeds }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.VoronoiSegmentationImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def voronoi_segmentation_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKVoronoi.VoronoiSegmentationImageFilter
    voronoi_segmentation_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    voronoi_segmentation_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def voronoi_segmentation_image_filter_base(*args: itkt.ImageLike,  number_of_seeds: int=..., min_region: int=..., steps: int=..., use_background_in_a_prior: bool=..., output_boundary: bool=..., interactive_segmentation: bool=..., mean_deviation: float=..., size: Sequence[int]=..., seeds=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for VoronoiSegmentationImageFilterBase"""
    import itk

    kwarg_typehints = { 'number_of_seeds':number_of_seeds,'min_region':min_region,'steps':steps,'use_background_in_a_prior':use_background_in_a_prior,'output_boundary':output_boundary,'interactive_segmentation':interactive_segmentation,'mean_deviation':mean_deviation,'size':size,'seeds':seeds }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.VoronoiSegmentationImageFilterBase.New(*args, **kwargs)

    return instance.__internal_call__()

def voronoi_segmentation_image_filter_base_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKVoronoi.VoronoiSegmentationImageFilterBase
    voronoi_segmentation_image_filter_base.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    voronoi_segmentation_image_filter_base.__doc__ = filter_object.__doc__



